Utilities
==============================

.. contents::
    :depth: 2
    :local:


.. currentmodule:: cr.nimble


Data Type Management
---------------------------


.. autosummary::
    :toctree: _autosummary

    promote_arg_dtypes
    check_shapes_are_equal
    canonicalize_dtype
    promote_to_complex
    promote_to_real
    integer_types
    integer_ranges
    dtype_ranges

System Information
-----------------------------

.. autosummary::
    :toctree: _autosummary

    platform
    is_cpu
    is_gpu
    is_tpu
    nbytes_live_buffers



